#
# spec file for package kubectl-klock
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubectl-klock
Version:        0.8.1
Release:        1.1
Summary:        Kubectl plugin to render watch output in a more readable fashion
License:        GPL-3.0-or-later AND Apache-2.0 AND CC-BY-4.0 AND CC0-1.0
URL:            https://github.com/applejag/kubectl-klock
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  golang(API) >= 1.24
BuildRequires:  zsh
BuildRequires:  fdupes

%description
A kubectl plugin to render the kubectl get pods --watch output in a much more
readable fashion.

Think of it as running watch kubectl get pods, but instead of polling, it uses
the regular watch feature to stream updates as soon as they occur.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build \
   -ldflags="-X main.version=v%{version}"

%install
# Install the binary.
install -D -m 0755 %{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check
%{buildroot}/%{_bindir}/%{name} --version | grep %{version}

%files
%doc README.md
%license LICENSES/*
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Wed Jun  4 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.8.1:
  * Fix ANSI coloring issue (#159)
    Issue was that kubectl-klock always converted to (what it
    thought was the correct) RGB version of the kubecolor color.
    But the kubecolor color may use ANSI color codes that can be
    changed via the terminal emulator's theme settings, whereas RGB
    versions are not changed to fit the terminal emulator theme.
    With this change kubectl-klock will preseve the ANSI color
    codes correctly.
    Screenshots see
    https://github.com/applejag/kubectl-klock/releases/tag/v0.8.1
* Mon May 26 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.8.0:
  * New features
  - Auto-hide deleted after duration by @applejag in #154
    This adds a new flag --hide-deleted, which can be set to
    either a time duration (e.g 10s, 1m, but also supports
    additional units like 1d, 1w, not that it's super useful in
    this case... )
    When set, deleted rows will disappear after this duration.
  * To always hide deleted rows you can pass
  - -hide-deleted=true.
  * To revert back to v0.7.2's behavior of always showing
    deleted rows, pass --hide-deleted=false
    This includes a "behavioral breaking change ⚠️" as
  - -hide-deleted is by default set to 10s
  - Added environment variables support by @applejag in #154
    I always had some plumbing in kubectl-klock for using
    environment variables. But they never worked as intended, so
    it was never a supported use case. But now they do!
    Command-line flags can now be controlled via environment
    variables:
    export KLOCK_ALL_NAMESPACES="true"                     # --all-namespaces
    export KLOCK_FIELD_SELECTOR="status.phase!=Succeeded"  # --field-separator
    export KLOCK_HIDE_DELETED="false"                      # --hide-deleted
    export KLOCK_LABEL_COLUMNS="app.kubernetes.io/name"    # --label-columns
    export KLOCK_OUTPUT="wide"                             # --output
    export KLOCK_SELECTOR="team!=frontend"                 # --selector
    export KLOCK_WATCH_KUBECONFIG="true"                   # --watch-kubeconfig
    The command-line flags have precedense over the environment
    variables. So if you set KLOCK_ALL_NAMESPACES=true then you
    can revert the value by passing the flag
  - -all-namespaces=false
  - Use kubecolor coloring by @applejag in #150
    Now making use of kubecolor's table and help text coloring!
    This includes using kubecolor's ~/.kube/color.yaml config.
    For more information about kubecolor theme customization,
    see: https://kubecolor.github.io/customizing/themes/
  - Added options subcommand & hide "common flags" from kubectl
    klock --help by @applejag in #156
    This, together with the kubecolor help text coloring, makes
    kubectl klock --help much more readable.
    Help text for the "standard command-line flags" like --as,
  - -context, --kubeconfig, --token, etc have been moved to the
    options subcommand.
  * Changes
  - Changed d hotkey to show deleted rows instead of hiding by
    @applejag in #154
    With the addition on --hide-deleted flag, the d hotkey has
    been changed from "hide deleted rows" to "show hidden deleted
    rows".
  * Bug fixes
  - Fix --context flag completion by @applejag in #153
  * Dependencies
  - In summary, kubectl-klock is now built using Go 1.24.3 and
    using Kubernetes libraries for Kubernetes v1.33.1.
  - Bump the all group with 2 updates by @dependabot in #126
  - Bump github.com/charmbracelet/bubbletea from 1.2.1 to 1.2.2
    in the all group by @dependabot in #127
  - Bump the all group with 5 updates by @dependabot in #128
  - Bump github.com/charmbracelet/bubbletea from 1.2.3 to 1.2.4
    in the all group by @dependabot in #130
  - Bump markdownlint-cli2 from 0.15.0 to 0.16.0 in the all group
    by @dependabot in #131
  - Bump markdownlint-cli2 from 0.16.0 to 0.17.0 in the all group
    by @dependabot in #133
  - Update Go to 1.23.4 by @applejag in #134
  - Bump the all group with 4 updates by @dependabot in #132
  - Bump the all group with 4 updates by @dependabot in #135
  - Bump golang.org/x/net from 0.30.0 to 0.33.0 by @dependabot in
    [#136]
  - Bump github.com/charmbracelet/bubbletea from 1.2.4 to 1.3.0
    in the all group by @dependabot in #137
  - Bump the all group with 6 updates by @dependabot in #138
  - Bump github.com/charmbracelet/bubbletea from 1.3.3 to 1.3.4
    in the all group by @dependabot in #139
  - Bump the all group with 6 updates by @dependabot in #141
  - Bump golang.org/x/net from 0.33.0 to 0.36.0 by @dependabot in
    [#140]
  - Bump github.com/spf13/viper from 1.20.0 to 1.20.1 in the all
    group by @dependabot in #142
  - Bump github.com/fsnotify/fsnotify from 1.8.0 to 1.9.0 in the
    all group by @dependabot in #143
  - Bump github.com/charmbracelet/bubbles from 0.20.0 to 0.21.0
    in the all group by @dependabot in #144
  - Bump golang.org/x/net from 0.36.0 to 0.38.0 by @dependabot in
    [#145]
  - Bump the all group across 1 directory with 5 updates by
    @dependabot in #147
  - Bump markdownlint-cli2 from 0.17.2 to 0.18.0 in the all group
    by @dependabot in #148
  - Bump the all group with 4 updates by @dependabot in #149
  * Non-functional changes
  - Removed VERSION file in favor of automatic version detection
    by @applejag in #151
    I've also removed the CHANGELOG.md in favor of the notes I
    write here in GitHub releases. If you relied on that before,
    then I'm sorry for the inconvinience. But this improves
    maintainability for me.
  - Added build attestations by @applejag in #152
    Since this version you should be able to verify that release
    assets are built by me by running:
    gh attestation verify ./kubectl-klock_linux_amd64.tar.gz --repo applejag/kubectl-klock
  - Fixed goreleaser config warnings by @applejag in #155
* Thu May 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.7.2:
  * Update VERSION
  * Bump version in VERSION
  * Bump github.com/charmbracelet/bubbletea in the all group (#125)
  * Bump rajatjindal/krew-release-bot from 0.0.46 to 0.0.47 in the all group (#124)
  * Bump markdownlint-cli2 from 0.14.0 to 0.15.0 in the all group (#123)
  * Bump the all group with 2 updates (#122)
  * Bump the all group with 6 updates (#121)
  * Bump the all group with 5 updates (#119)
  * Bump github.com/charmbracelet/bubbles in the all group (#118)
  * Bump markdownlint-cli2 from 0.13.0 to 0.14.0 in the all group (#117)
* Thu May 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kubectl-klock: kubectl plugin to render watch output
  in a more readable fashion
